**`PgUp`** and **`PgDn`** scrolls up and down, the `/ss` command decides how much

**`Up`** and **`Down`** goes through the history of text you've written

**`Tab`** completes a nickname after writing the first couple letters

**`CTRL-A`** switches to the left window

**`CTRL-X`** switches to the right window

**`CTRL-E`** jumps to another channel, to the oldest unread message

**`CTRL-R`** is the `/r` command, redraws the screen to fix corruption. Use this if things are glitchy after resizing the window

**`CTRL-K`** followed by a number `0-9` or letter `a-f` changes colour mid-message, see `/cmap`

**`CTRL-O`** changes back to default colour
